# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## [0.0.3] - 2020-08-07

### Fixed
- Missing markdown files (including CHANGELOG.md)

### Changed
- Added ability to use via pipx
- Added installation and run options on README

## [0.0.2] - 2020-08-06

### Fixed
- Windows setup/config file issue when UTF-8 not specified

### Changed
- Minor README updates

## [0.0.1] - 2020-08-06
- Initial release on GitHub and PyPI